### Contribution of Users in Chat by Hour
I splitted a day into 8 equal parts and extracted statistics of activity ( mine & others too ) for each of those timespans, to learn when users are more active. And no doubt result was interesting _( atleast for Group Chat :wink: )_.

- 00:00:00 - 02:59:59
- 03:00:00 - 05:59:59
- 06:00:00 - 08:59:59
- 09:00:00 - 11:59:59
- 12:00:00 - 14:59:59
- 15:00:00 - 17:59:59
- 18:00:00 - 20:59:59
- 21:00:00 - 23:59:59

Following Pie charts show how two participants contributed to a Private chat i.e. how much active were they at which time period.

![activityOfParticipantOne](../plots/contributionInPrivateChatOf*******oyByHour.png)

![activityOfParticipantTwo](../plots/contributionInPrivateChatOf******************atty_\)ByHour.png)

Following Pie charts showing how participants were contributing in a Group Chat.

![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************SS\)ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************597ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************377ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************965ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************316ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************895ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************494ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************013ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf*************CSS\)ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf**********749ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************858ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf*********SS\)ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************537ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************334ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************422ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************058ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf*************8347ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************456ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************4775ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************181ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************691ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************459ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************093ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************979ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************697ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************183ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************502ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************606ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf*******oyByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************849ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************116ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************CSS\)ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************421ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************848ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************963ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************2_78ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************051ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf*********S\)ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************454ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************877ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************592ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************203ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************425ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************382ByHour.png)
![activityOfParticipantInGroupChat](../plots/contributionInGroupChatOf************669ByHour.png)
